fileeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# fileeditor

class `camelot.view.controls.editors.fileeditor.` `FileEditor`(parent=None, storage=None, field_name='file', remove_original=False, **kwargs)

  Widget for editing File fields

  `setup_widget`()

    Called inside init, overwrite this method for custom file edit widgets

  `stored_file_ready`(stored_file)

    Slot to be called when a new stored_file has been created by the storage

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus